from setuptools import setup, find_packages

# Setting Up

setup(
      
      name = "pyerualjetwork",
      version = "1.2.7",
      author = "Hasan Can Beydili",
      author_email = "tchasancan@gmail.com",
      description= "Advanced python deep learning library. 'ThresholdSigns' changed to 'MembranThresholds' and 'ThresholdValues' changed to 'MembranPotentials'. (Documentation in desc. Examples in GİTHUB: https://github.com/HCB06/PyerualJetwork)",
      packages = find_packages(),
      keywords = ["model evaluation", "classifcation", 'pruning learning artficial neural networks']
      
      )